@@ -120,7 +120,10 @@ def mk_push_target(ds, name, path, annex=True, bare=True):
         # commit for the managed branch.
         # the only sane approach is to let git-annex establish a shared
         # history
-        ds.repo.call_annex(['sync'])
+        if AnnexRepo.git_annex_version > "8.20210631":
+            ds.repo.call_annex(['sync', '--allow-unrelated-histories'])
+        else:
+            ds.repo.call_annex(['sync'])
         ds.repo.call_annex(['sync', '--cleanup'])
     return target
 
